glob_match

Function glob_match 

pub fn glob_match(pattern: &str, text: &str) -> bool
Match a tool or path name against a minimal * wildcard pattern.

* matches any byte sequence, including empty. Every other byte matches literally. The iterative implementation is bounded and does not recurse, including for adversarial patterns with many stars.